"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.evaluateActions = void 0;
const core_1 = require("@checkup/core");
function evaluateActions(taskResult, taskConfig) {
    let { values: dependenciesCount, total: totalDependencies } = taskResult.result[0].dataSummary;
    let outdatedCount = Object.values(dependenciesCount).reduce((total, count) => total + count, 0);
    let actionsEvaluator = new core_1.ActionsEvaluator();
    actionsEvaluator.add({
        name: 'reduce-outdated-major-dependencies',
        summary: 'Update outdated major versions',
        details: `${dependenciesCount.major} major versions outdated`,
        defaultThreshold: 0.05,
        items: [],
        input: dependenciesCount.major / totalDependencies,
    });
    actionsEvaluator.add({
        name: 'reduce-outdated-minor-dependencies',
        summary: 'Update outdated minor versions',
        details: `${dependenciesCount.minor} minor versions outdated`,
        defaultThreshold: 0.05,
        items: [],
        input: dependenciesCount.minor / totalDependencies,
    });
    actionsEvaluator.add({
        name: 'reduce-outdated-dependencies',
        summary: 'Update outdated versions',
        details: `${core_1.toPercent(outdatedCount / totalDependencies)} of versions outdated`,
        defaultThreshold: 0.2,
        items: [],
        input: outdatedCount / totalDependencies,
    });
    return actionsEvaluator.evaluate(taskConfig);
}
exports.evaluateActions = evaluateActions;
//# sourceMappingURL=outdated-dependency-actions.js.map